PyXMake Developer Guide: PyXMake.Plugin.__gitlab Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions | Variables
PyXMake.Plugin.__gitlab Namespace Reference

## Functions
| check ()
| housekeeping (**kwargs)
| release (**kwargs)
| main (**kwargs)

## Variables
| LooseVersion = StrictVersion

## Detailed Description

    GitLab release configuration and management assistance wrapper.

    @note:
    Created on 16.08.2022

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          -

    @change:
          -

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ check()

PyXMake.Plugin.__gitlab.check | ( |  | ) |

    GitLab CI methods are only available in CI environment.

Definition at line 40 of file __gitlab.py.

## ◆ housekeeping()

PyXMake.Plugin.__gitlab.housekeeping | ( | ** | kwargs | ) |

    Entry point for housekeeping job.

Definition at line 48 of file __gitlab.py.

## ◆ main()

PyXMake.Plugin.__gitlab.main | ( | ** | kwargs | ) |

    Main command line parser.

Definition at line 198 of file __gitlab.py.

## ◆ release()

PyXMake.Plugin.__gitlab.release | ( | ** | kwargs | ) |

    Entry point for release job.

Definition at line 72 of file __gitlab.py.

## Variable Documentation

## ◆ LooseVersion

PyXMake.Plugin.__gitlab.LooseVersion = StrictVersion

Definition at line 31 of file __gitlab.py.